/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Command line was: qdbusxml2cpp -m -i dbusutils_p.h -p krunner_iface /usr/src/ports/kf5-krunner/kf5-krunner-5.43.0-1.x86_64/src/krunner-5.43.0/src/data/org.kde.krunner1.xml
 *
 * qdbusxml2cpp is Copyright (C) 2017 The Qt Company Ltd.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef KRUNNER_IFACE_H
#define KRUNNER_IFACE_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>
#include "dbusutils_p.h"

/*
 * Proxy class for interface org.kde.krunner1
 */
class OrgKdeKrunner1Interface: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "org.kde.krunner1"; }

public:
    OrgKdeKrunner1Interface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~OrgKdeKrunner1Interface();

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<RemoteActions> Actions()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("Actions"), argumentList);
    }

    inline QDBusPendingReply<RemoteMatches> Match(const QString &query)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(query);
        return asyncCallWithArgumentList(QStringLiteral("Match"), argumentList);
    }

    inline QDBusPendingReply<> Run(const QString &matchId, const QString &actionId)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(matchId) << QVariant::fromValue(actionId);
        return asyncCallWithArgumentList(QStringLiteral("Run"), argumentList);
    }

Q_SIGNALS: // SIGNALS
};

namespace org {
  namespace kde {
    typedef ::OrgKdeKrunner1Interface krunner1;
  }
}
#endif
