/****************************************************************************
** Meta object code from reading C++ file 'abstractrunner.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/krunner-5.43.0/src/abstractrunner.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'abstractrunner.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Plasma__AbstractRunner_t {
    QByteArrayData data[12];
    char stringdata0[117];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Plasma__AbstractRunner_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Plasma__AbstractRunner_t qt_meta_stringdata_Plasma__AbstractRunner = {
    {
QT_MOC_LITERAL(0, 0, 22), // "Plasma::AbstractRunner"
QT_MOC_LITERAL(1, 23, 7), // "prepare"
QT_MOC_LITERAL(2, 31, 0), // ""
QT_MOC_LITERAL(3, 32, 8), // "teardown"
QT_MOC_LITERAL(4, 41, 17), // "matchingSuspended"
QT_MOC_LITERAL(5, 59, 9), // "suspended"
QT_MOC_LITERAL(6, 69, 10), // "dataEngine"
QT_MOC_LITERAL(7, 80, 11), // "DataEngine*"
QT_MOC_LITERAL(8, 92, 4), // "name"
QT_MOC_LITERAL(9, 97, 2), // "id"
QT_MOC_LITERAL(10, 100, 11), // "description"
QT_MOC_LITERAL(11, 112, 4) // "icon"

    },
    "Plasma::AbstractRunner\0prepare\0\0"
    "teardown\0matchingSuspended\0suspended\0"
    "dataEngine\0DataEngine*\0name\0id\0"
    "description\0icon"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Plasma__AbstractRunner[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       4,   14, // methods
       5,   42, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       3,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   34,    2, 0x06 /* Public */,
       3,    0,   35,    2, 0x06 /* Public */,
       4,    1,   36,    2, 0x06 /* Public */,

 // methods: name, argc, parameters, tag, flags
       6,    1,   39,    2, 0x01 /* Protected */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    5,

 // methods: parameters
    0x80000000 | 7, QMetaType::QString,    8,

 // properties: name, type, flags
       4, QMetaType::Bool, 0x00495003,
       9, QMetaType::QString, 0x00095001,
      10, QMetaType::QString, 0x00095001,
       8, QMetaType::QString, 0x00095001,
      11, QMetaType::QIcon, 0x00095001,

 // properties: notify_signal_id
       2,
       0,
       0,
       0,
       0,

       0        // eod
};

void Plasma::AbstractRunner::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        AbstractRunner *_t = static_cast<AbstractRunner *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->prepare(); break;
        case 1: _t->teardown(); break;
        case 2: _t->matchingSuspended((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 3: { DataEngine* _r = _t->dataEngine((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< DataEngine**>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (AbstractRunner::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&AbstractRunner::prepare)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (AbstractRunner::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&AbstractRunner::teardown)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (AbstractRunner::*_t)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&AbstractRunner::matchingSuspended)) {
                *result = 2;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        AbstractRunner *_t = static_cast<AbstractRunner *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< bool*>(_v) = _t->isMatchingSuspended(); break;
        case 1: *reinterpret_cast< QString*>(_v) = _t->id(); break;
        case 2: *reinterpret_cast< QString*>(_v) = _t->description(); break;
        case 3: *reinterpret_cast< QString*>(_v) = _t->name(); break;
        case 4: *reinterpret_cast< QIcon*>(_v) = _t->icon(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        AbstractRunner *_t = static_cast<AbstractRunner *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->suspendMatching(*reinterpret_cast< bool*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

const QMetaObject Plasma::AbstractRunner::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_Plasma__AbstractRunner.data,
      qt_meta_data_Plasma__AbstractRunner,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Plasma::AbstractRunner::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Plasma::AbstractRunner::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Plasma__AbstractRunner.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Plasma::AbstractRunner::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 4;
    }
#ifndef QT_NO_PROPERTIES
   else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 5;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 5;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 5;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 5;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 5;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void Plasma::AbstractRunner::prepare()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Plasma::AbstractRunner::teardown()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Plasma::AbstractRunner::matchingSuspended(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
