/****************************************************************************
** Meta object code from reading C++ file 'runnermodel.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/krunner-5.43.0/src/declarative/runnermodel.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'runnermodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_RunnerModel_t {
    QByteArrayData data[18];
    char stringdata0[196];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_RunnerModel_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_RunnerModel_t qt_meta_stringdata_RunnerModel = {
    {
QT_MOC_LITERAL(0, 0, 11), // "RunnerModel"
QT_MOC_LITERAL(1, 12, 12), // "queryChanged"
QT_MOC_LITERAL(2, 25, 0), // ""
QT_MOC_LITERAL(3, 26, 12), // "countChanged"
QT_MOC_LITERAL(4, 39, 14), // "runnersChanged"
QT_MOC_LITERAL(5, 54, 14), // "runningChanged"
QT_MOC_LITERAL(6, 69, 7), // "running"
QT_MOC_LITERAL(7, 77, 13), // "scheduleQuery"
QT_MOC_LITERAL(8, 91, 5), // "query"
QT_MOC_LITERAL(9, 97, 10), // "startQuery"
QT_MOC_LITERAL(10, 108, 14), // "matchesChanged"
QT_MOC_LITERAL(11, 123, 25), // "QList<Plasma::QueryMatch>"
QT_MOC_LITERAL(12, 149, 7), // "matches"
QT_MOC_LITERAL(13, 157, 16), // "queryHasFinished"
QT_MOC_LITERAL(14, 174, 3), // "run"
QT_MOC_LITERAL(15, 178, 3), // "row"
QT_MOC_LITERAL(16, 182, 7), // "runners"
QT_MOC_LITERAL(17, 190, 5) // "count"

    },
    "RunnerModel\0queryChanged\0\0countChanged\0"
    "runnersChanged\0runningChanged\0running\0"
    "scheduleQuery\0query\0startQuery\0"
    "matchesChanged\0QList<Plasma::QueryMatch>\0"
    "matches\0queryHasFinished\0run\0row\0"
    "runners\0count"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_RunnerModel[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       9,   14, // methods
       4,   76, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       4,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   59,    2, 0x06 /* Public */,
       3,    0,   60,    2, 0x06 /* Public */,
       4,    0,   61,    2, 0x06 /* Public */,
       5,    1,   62,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       7,    1,   65,    2, 0x0a /* Public */,
       9,    0,   68,    2, 0x08 /* Private */,
      10,    1,   69,    2, 0x08 /* Private */,
      13,    0,   72,    2, 0x08 /* Private */,

 // methods: name, argc, parameters, tag, flags
      14,    1,   73,    2, 0x42 /* Public | isScriptable */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    6,

 // slots: parameters
    QMetaType::Void, QMetaType::QString,    8,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 11,   12,
    QMetaType::Void,

 // methods: parameters
    QMetaType::Void, QMetaType::Int,   15,

 // properties: name, type, flags
       8, QMetaType::QString, 0x00495003,
      16, QMetaType::QStringList, 0x00495103,
      17, QMetaType::Int, 0x00495001,
       6, QMetaType::Bool, 0x00495001,

 // properties: notify_signal_id
       0,
       2,
       1,
       3,

       0        // eod
};

void RunnerModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        RunnerModel *_t = static_cast<RunnerModel *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->queryChanged(); break;
        case 1: _t->countChanged(); break;
        case 2: _t->runnersChanged(); break;
        case 3: _t->runningChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 4: _t->scheduleQuery((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 5: _t->startQuery(); break;
        case 6: _t->matchesChanged((*reinterpret_cast< const QList<Plasma::QueryMatch>(*)>(_a[1]))); break;
        case 7: _t->queryHasFinished(); break;
        case 8: _t->run((*reinterpret_cast< int(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (RunnerModel::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&RunnerModel::queryChanged)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (RunnerModel::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&RunnerModel::countChanged)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (RunnerModel::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&RunnerModel::runnersChanged)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (RunnerModel::*_t)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&RunnerModel::runningChanged)) {
                *result = 3;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        RunnerModel *_t = static_cast<RunnerModel *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QString*>(_v) = _t->currentQuery(); break;
        case 1: *reinterpret_cast< QStringList*>(_v) = _t->runners(); break;
        case 2: *reinterpret_cast< int*>(_v) = _t->count(); break;
        case 3: *reinterpret_cast< bool*>(_v) = _t->isRunning(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        RunnerModel *_t = static_cast<RunnerModel *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->scheduleQuery(*reinterpret_cast< QString*>(_v)); break;
        case 1: _t->setRunners(*reinterpret_cast< QStringList*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

const QMetaObject RunnerModel::staticMetaObject = {
    { &QAbstractListModel::staticMetaObject, qt_meta_stringdata_RunnerModel.data,
      qt_meta_data_RunnerModel,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *RunnerModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *RunnerModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_RunnerModel.stringdata0))
        return static_cast<void*>(this);
    return QAbstractListModel::qt_metacast(_clname);
}

int RunnerModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractListModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 9;
    }
#ifndef QT_NO_PROPERTIES
   else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 4;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 4;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 4;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 4;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 4;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void RunnerModel::queryChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void RunnerModel::countChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void RunnerModel::runnersChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void RunnerModel::runningChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
