/****************************************************************************
** Meta object code from reading C++ file 'runnermanager.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/krunner-5.43.0/src/runnermanager.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'runnermanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Plasma__RunnerManager_t {
    QByteArrayData data[17];
    char stringdata0[249];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Plasma__RunnerManager_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Plasma__RunnerManager_t qt_meta_stringdata_Plasma__RunnerManager = {
    {
QT_MOC_LITERAL(0, 0, 21), // "Plasma::RunnerManager"
QT_MOC_LITERAL(1, 22, 14), // "matchesChanged"
QT_MOC_LITERAL(2, 37, 0), // ""
QT_MOC_LITERAL(3, 38, 25), // "QList<Plasma::QueryMatch>"
QT_MOC_LITERAL(4, 64, 7), // "matches"
QT_MOC_LITERAL(5, 72, 13), // "queryFinished"
QT_MOC_LITERAL(6, 86, 17), // "setupMatchSession"
QT_MOC_LITERAL(7, 104, 20), // "matchSessionComplete"
QT_MOC_LITERAL(8, 125, 11), // "launchQuery"
QT_MOC_LITERAL(9, 137, 4), // "term"
QT_MOC_LITERAL(10, 142, 8), // "runnerId"
QT_MOC_LITERAL(11, 151, 5), // "reset"
QT_MOC_LITERAL(12, 157, 22), // "scheduleMatchesChanged"
QT_MOC_LITERAL(13, 180, 7), // "jobDone"
QT_MOC_LITERAL(14, 188, 24), // "ThreadWeaver::JobPointer"
QT_MOC_LITERAL(15, 213, 11), // "unblockJobs"
QT_MOC_LITERAL(16, 225, 23) // "runnerMatchingSuspended"

    },
    "Plasma::RunnerManager\0matchesChanged\0"
    "\0QList<Plasma::QueryMatch>\0matches\0"
    "queryFinished\0setupMatchSession\0"
    "matchSessionComplete\0launchQuery\0term\0"
    "runnerId\0reset\0scheduleMatchesChanged\0"
    "jobDone\0ThreadWeaver::JobPointer\0"
    "unblockJobs\0runnerMatchingSuspended"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Plasma__RunnerManager[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      12,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   74,    2, 0x06 /* Public */,
       5,    0,   77,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       6,    0,   78,    2, 0x0a /* Public */,
       7,    0,   79,    2, 0x0a /* Public */,
       8,    2,   80,    2, 0x0a /* Public */,
       8,    1,   85,    2, 0x0a /* Public */,
      11,    0,   88,    2, 0x0a /* Public */,
      12,    0,   89,    2, 0x08 /* Private */,
       1,    0,   90,    2, 0x08 /* Private */,
      13,    1,   91,    2, 0x08 /* Private */,
      15,    0,   94,    2, 0x08 /* Private */,
      16,    1,   95,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,    9,   10,
    QMetaType::Void, QMetaType::QString,    9,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 14,    2,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    2,

       0        // eod
};

void Plasma::RunnerManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        RunnerManager *_t = static_cast<RunnerManager *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->matchesChanged((*reinterpret_cast< const QList<Plasma::QueryMatch>(*)>(_a[1]))); break;
        case 1: _t->queryFinished(); break;
        case 2: _t->setupMatchSession(); break;
        case 3: _t->matchSessionComplete(); break;
        case 4: _t->launchQuery((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 5: _t->launchQuery((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 6: _t->reset(); break;
        case 7: _t->d->scheduleMatchesChanged(); break;
        case 8: _t->d->matchesChanged(); break;
        case 9: _t->d->jobDone((*reinterpret_cast< ThreadWeaver::JobPointer(*)>(_a[1]))); break;
        case 10: _t->d->unblockJobs(); break;
        case 11: _t->d->runnerMatchingSuspended((*reinterpret_cast< bool(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (RunnerManager::*_t)(const QList<Plasma::QueryMatch> & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&RunnerManager::matchesChanged)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (RunnerManager::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&RunnerManager::queryFinished)) {
                *result = 1;
                return;
            }
        }
    }
}

const QMetaObject Plasma::RunnerManager::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_Plasma__RunnerManager.data,
      qt_meta_data_Plasma__RunnerManager,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Plasma::RunnerManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Plasma::RunnerManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Plasma__RunnerManager.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Plasma::RunnerManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void Plasma::RunnerManager::matchesChanged(const QList<Plasma::QueryMatch> & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void Plasma::RunnerManager::queryFinished()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
